@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -12,15 +12,12 @@ import enum
 import unittest
 
 from traits.api import (
-    Any, BaseEnum, Enum, HasTraits, List, Property, TraitError)
-from traits.testing.optional_dependencies import pyface, requires_traitsui
+    Any, BaseEnum, Enum, HasTraits, Int, List, Property, Set, TraitError,
+    Tuple)
+from traits.etsconfig.api import ETSConfig
+from traits.testing.optional_dependencies import requires_traitsui
 
-if pyface is not None:
-    GuiTestAssistant = pyface.toolkit.toolkit_object(
-        "util.gui_test_assistant:GuiTestAssistant")
-else:
-    class GuiTestAssistant:
-        pass
+is_null = ETSConfig.toolkit == 'null'
 
 
 class FooEnum(enum.Enum):
@@ -312,17 +309,46 @@ class EnumTestCase(unittest.TestCase):
             obj.slow_enum = "perhaps"
         self.assertEqual(obj.slow_enum, "no")
 
+    def test_dynamic_enum_in_tuple(self):
+        # Regression test for #1385. The previous implementation of Enum
+        # did no validation until trait-set time, but for an Enum inside
+        # a Tuple, the inner traits are never set.
+
+        class HasEnumInTuple(HasTraits):
+            #: List of valid month numbers.
+            months = List(Int, value=[1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12])
+
+            #: (Year, month) pairs.
+            year_and_month = Tuple(Int(), Enum(values='months'))
+
+        model = HasEnumInTuple()
+        model.year_and_month = (1974, 8)
+        self.assertEqual(model.year_and_month, (1974, 8))
+        with self.assertRaises(TraitError):
+            model.year_and_month = 1986, 13
+
+    def test_dynamic_enum_in_list(self):
+        # Another regression test for #1385.
+        class HasEnumInList(HasTraits):
+            #: Valid digits
+            digits = Set(Int)
+
+            #: Sequence of those digits
+            digit_sequence = List(Enum(values="digits"))
+
+        model = HasEnumInList(digits={-1, 0, 1})
+        model.digit_sequence = [-1, 0, 1, 1]
+        with self.assertRaises(TraitError):
+            model.digit_sequence = [-1, 0, 2, 1]
+
 
 @requires_traitsui
-class TestGui(GuiTestAssistant, unittest.TestCase):
+@unittest.skipIf(is_null, "GUI toolkit not available")
+class TestGui(unittest.TestCase):
 
     def test_create_editor(self):
-        obj = EnumCollectionGUIExample()
+        from traitsui.testing.api import UITester
 
-        # Create a UI window
-        ui = obj.edit_traits()
-        try:
-            self.gui.process_events()
-        finally:
-            with self.delete_widget(ui.control):
-                ui.dispose()
+        obj = EnumCollectionGUIExample()
+        with UITester().create_ui(obj):
+            pass
