@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -1011,7 +1011,7 @@ class ListenerParser(HasPrivateTraits):
 
     def __init__(self, text="", **traits):
         self.text = text
-        super(ListenerParser, self).__init__(**traits)
+        super().__init__(**traits)
 
     # -- Private Methods ------------------------------------------------------
 
